import { routerRedux } from 'dva/router';
import { message } from 'antd';
import {
  createImage,
  deleteImage,
  queryImageResource,
  queryVideoResource,
} from '../services/resource';

export default {
  namespace: 'resource',

  state: {
    list: [],
    pageNo: 1,
    pageSize: 15,
    totalSize: 0,
  },

  effects: {
    *fetchImageList({ payload }, { call, put }) {
      const response = yield call(queryImageResource, payload);
      if (response.success) {
        message.success('加载图片列表成功');
        yield put({
          type: 'querySuccess',
          payload: {
            list: response.data.list || [],
            pageSize: response.data.pageSize,
            totalSize: response.data.totalSize,
            pageNo: response.data.pageNo,
          },
        });
      }
    },
    *fetchVideoList({ payload }, { call, put }) {
      const response = yield call(queryVideoResource, payload);
      if (response.success) {
        message.success('加载视频列表成功');
        yield put({
          type: 'querySuccess',
          payload: {
            list: response.data.list || [],
            pageSize: response.data.pageSize,
            totalSize: response.data.totalSize,
            pageNo: response.data.pageNo,
          },
        });
      }
    },
    *createImage({ payload }, { call, put }) {
      const response = yield call(createImage, payload);
      if (response.success) {
        message.success('创建成功');
        yield put(routerRedux.goBack());
      }
    },
    *deleteImage({ payload }, { call, put }) {
      const response = yield call(deleteImage, payload);
      if (response && response.success) {
        message.success('删除成功');
      }
    }
  },

  reducers: {
    querySuccess(state, action) {
      return {
        ...state,
        ...action.payload,
      };
    },
  },
};
