import React, { PureComponent } from 'react';
import { connect } from 'dva';
import { routerRedux } from 'dva/router';
import { Card, Form, Input, Button } from 'antd';
import { toDecimal2 } from '../../utils/utils';
import styles from './MerchantDespoit.less';

const fieldLabels = {
  code: '商户编号',
  name: '商户名称',
  balance: '账户余额',
  quantity: '充值金额',
  note: '备注',
};
const formItemLayout = {
  labelCol: {
    xs: { span: 24 },
    sm: { span: 6 },
  },
  wrapperCol: {
    xs: { span: 24 },
    sm: { span: 14 },
    md: { span: 12 },
  },
};
const submitFormLayout = {
  wrapperCol: {
    xs: { span: 24, offset: 0 },
    sm: { span: 12, offset: 6 },
  },
};

@Form.create()
@connect(({loading, merchant}) => ({
  merchant,
  submitting: loading.models.merchant,
}))
export default class MerchantDespoitPage extends PureComponent {
  handlePageBack = () => {
    this.props.dispatch(routerRedux.push({
      pathname: '/merchant/list',
      state: this.props.location.state,
    }));
  }
  handlePageSubmit = (e) => {
    e.preventDefault();
    this.props.form.validateFieldsAndScroll((err, values) => {
      if (!err) {
        const { note, quantity } = values;
        const { id } = this.props.location.state.currentItem;
        this.props.dispatch({
          type: 'merchant/despoitMerchantItem',
          payload: {
            note,
            quantity,
            merchantId: id,
          },
          states: this.props.location.state,
        });
      }
    });
  }
  render() {
    const { location, form, submitting } = this.props;
    const { currentItem } = location.state;
    const { getFieldDecorator } = form;
    return (
      <Card>
        <Form onSubmit={this.handlePageSubmit}>
          <Form.Item label={fieldLabels.name} {...formItemLayout}>
            <span>{`${currentItem.name}【${currentItem.code}】`}</span>
          </Form.Item>
          <Form.Item label={fieldLabels.balance} {...formItemLayout}>
            <span className={styles.balance}>{toDecimal2(currentItem.balance)}元</span>
          </Form.Item>
          <Form.Item label={fieldLabels.quantity} {...formItemLayout}>
            {getFieldDecorator('quantity', {
              rules: [
                {
                  required: true, type: 'string', message: '充值金额不能为空!',
                }, {
                  pattern: /(^[1-9]([0-9]+)?(\.[0-9]{1,2})?$)|(^(0){1}$)|(^[0-9]\.[0-9]([0-9])?$)/, message: '充值金额格式错误!',
                }
              ],
            })(
              <Input placeholder="请输入充值金额" addonAfter="元" />
            )}
          </Form.Item>
          <Form.Item label={fieldLabels.note} {...formItemLayout}>
            {getFieldDecorator('note', {
            })(
              <Input placeholder="请输入" />
            )}
          </Form.Item>
          <Form.Item {...submitFormLayout} style={{ marginTop: 32 }}>
            <Button
              onClick={this.handlePageBack}
            >取消
            </Button>
            <Button
              type="primary"
              htmlType="submit"
              loading={submitting}
              style={{ marginLeft: 8 }}
            >提交
            </Button>
          </Form.Item>
        </Form>
      </Card>
    );
  }
}
