import React from 'react';
import { PictureItem } from '../../components/RBItem';
import { StandardCardList } from '../../components/RBList';

function pictureItemFormatter(originData) {
  return originData.map((item) => {
    return {
      id: item.id,
      picPath: item.path,
      picCode: item.code,
      picStatus: item.state,
    };
  });
}

function PictureCardList({
  UIParams, dataSource, loading, totalSize, pageSize, pageNo,
  onFilterClick, onCreateClick, onBatchClick, onDeleteClick,
}) {
  const batchActions = [{
    key: 'delete',
    name: '批量删除',
  }, {
    key: 'edit',
    name: '批量编辑',
  }];
  const basicSearch = {
    keys: [{
      name: '图片编号',
      field: 'code',
    }, {
      name: '图片名称',
      field: 'name',
    }],
  };
  const pagination = {
    pageNo,
    pageSize,
    totalSize,
  };
  return (
    <StandardCardList
      loading={loading}
      component={PictureItem}
      keepUIState={{ ...UIParams }}
      dataSource={pictureItemFormatter(dataSource)}
      header={{basicSearch, onFilterClick, onCreateClick}}
      footer={{pagination, batchActions, onBatchClick}}
      grid={{ gutter: 16, xxl: 12, xl: 6, lg: 4, md: 3, sm: 2, xs: 1 }}
      onDelete={onDeleteClick}
    />
  );
}

export default PictureCardList;
