import React from 'react';
import moment from 'moment';
import { Divider, message } from 'antd';
import { ossHost } from '../../utils/config';
import { renderStatus, addRowKey } from '../../utils/utils';
import { StandardTableList } from '../../components/RBList';
import styles from './PictureTableList.less';

function PictureTableList({
  UIParams, dataSource, loading, totalSize, pageSize, pageNo,
  onFilterClick, onCreateClick, onBatchClick, onDeleteClick,
}) {
  const batchActions = [{
    key: 'delete',
    name: '批量删除',
  }, {
    key: 'edit',
    name: '批量编辑',
  }];
  const basicSearch = {
    keys: [{
      name: '图片编号',
      field: 'code',
    }, {
      name: '图片名称',
      field: 'name',
    }],
  };
  const pagination = {
    pageNo,
    pageSize,
    totalSize,
  };
  const renderThumbPic = (url) => {
    return (
      <div className={styles.thumbPic}>
        <img src={url} alt="thumb" />
      </div>
    );
  };
  const renderMetaData = ({ code, name }) => {
    return (
      <div className={styles.meta}>
        <p>{name}</p>
        <p>{code}</p>
      </div>
    );
  };
  const renderActions = () => {
    return (
      <div>
        <a>查看</a>
        <Divider type="vertical" />
        <a>编辑</a>
        <Divider type="vertical" />
        <a onClick={onDeleteClick}>删除</a>
      </div>
    );
  };
  const columns = [{
    title: '缩略图',
    key: 1,
    dataIndex: 'path',
    render: text => renderThumbPic(`${ossHost}/${text}`),
    width: '15%',
  }, {
    title: '名称/编号',
    key: 2,
    dataIndex: 'meta',
    render: (_, record) => renderMetaData(record),
    width: '25%',
  }, {
    title: '格式',
    key: 3,
    dataIndex: 'format',
    width: '10%',
  }, {
    title: '大小(Byte)',
    key: 4,
    dataIndex: 'size',
    width: '10%',
  }, {
    title: '状态',
    key: 5,
    dataIndex: 'status',
    render: text => renderStatus(text),
    width: '8%',
  }, {
    title: '更新日期',
    key: 6,
    dataIndex: 'gmtModified',
    render: text => moment(text).format('YYYY-MM-DD HH:mm:ss'),
    width: '17%',
  }, {
    title: '操作',
    key: 7,
    dataIndex: 'action',
    render: (_, record) => renderActions(record),
    width: '15%',
  }];

  return (
    <StandardTableList
      columns={columns}
      loading={loading}
      dataSource={addRowKey(dataSource)}
      keepUIState={{...UIParams}}
      header={{basicSearch, onFilterClick, onCreateClick}}
      footer={{pagination, batchActions, onBatchClick}}
    />
  );
}

export default PictureTableList;
