import React, { Component } from 'react';
import { connect } from 'dva';
import { Card, Button, message } from 'antd';
import RBVideoPlayer from '../../components/RBVideoPlayer';
import VideoPlayList from './VideoPlayList';
import VideoTableList from './VideoTableList';
import { addRowKey } from '../../utils/utils';

const Message = message;

function deleteBlankKey(obj) {
  if (!(typeof obj === 'object')) {
    return;
  }
  let newObj = {...obj};
  for (let key in newObj) {
    if (newObj.hasOwnProperty(key) && !newObj[key]) {
      delete newObj[key];
    }
  }
  return newObj;
}

@connect(({ loading, resource }) => ({
  resource,
  loading: loading.models.resource,
}))
export default class VideoListPage extends Component {
  constructor(props) {
    super(props);
    this.state = {
      isCard: true,
      destory: true,
      current: {},
    }
  }
  componentDidMount() {
    this.props.dispatch({
      type: 'resource/fetchVideoList',
      payload: {},
    });
  }
  handleShowTypeChange = () => {
    this.setState({ isCard: !!!this.state.isCard });
  }
  handleFilterOperation = (params) => {
    const newParams = deleteBlankKey(params);
    this.props.dispatch({
      type: 'resource/fetchVideoList',
      payload: newParams,
    });
  }
  handleBatchOperation = () => {
    Message.info('暂不支持批量操作!');
  }
  handleModalDestory = () => {
    this.setState({ destory: true });
  }
  handleModalCreate = (item) => {
    this.setState({ destory: false, current: item });
  }

  render() {
    const { loading, resource } = this.props;
    const { list, totalSize, pageSize, pageNo } = resource;
    const publicProps = {
      loading,
      pageNo,
      pageSize,
      totalSize,
      dataSource: addRowKey(list),
      onFilterClick: this.handleFilterOperation,
    };
    return (
      <Card bordered={false}>
        <Button.Group style={{marginBottom: 16}}>
          <Button
            style={{width: 50}}
            onClick={this.handleShowTypeChange}
            icon="appstore-o"
            type={this.state.isCard ? 'primary' : null}
          />
          <Button
            style={{width: 50}}
            onClick={this.handleShowTypeChange}
            icon="table"
            type={this.state.isCard ? null : 'primary'}
          />
        </Button.Group>
        {this.state.isCard ?
          <VideoPlayList {...publicProps} /> :
          <VideoTableList
            {...publicProps}
            currentItem={this.state.current}
            modalDestory={this.state.destory}
            onModalDestory={this.handleModalDestory}
            onModalCreate={this.handleModalCreate}
            onBatchClick={this.handleBatchOperation}
          />
        }
      </Card>
    );
  }
}
