import React from 'react';
import moment from 'moment';
import { Card, Badge, Modal, message } from 'antd';
import { ossHost } from '../../utils/config';
import { StandardTableList } from '../../components/RBList';
import RBVideoPlayer from '../../components/RBVideoPlayer';
import { renderStatus } from '../../utils/utils';

function VideoTableList({
  dataSource, loading, totalSize, pageSize, pageNo, modalDestory, currentItem,
  onFilterClick, onBatchClick, onModalCreate, onModalDestory,
}) {
  const renderQuality = (quality) => {
    if (quality === 'high') {
      return '高清';
    } else {
      return '标清';
    }
  };
  const pagination = {
    pageNo,
    pageSize,
    totalSize,
  };
  const batchActions = [{
    key: 'delete',
    name: '批量删除',
  }, {
    key: 'edit',
    name: '批量编辑',
  }];
  const basicSearch = {
    keys: [{
      name: '视频编号',
      field: 'code',
    }, {
      name: '视频名称',
      field: 'name',
    }],
  };
  const columns = [{
    title: '视频编号',
    key: 1,
    dataIndex: 'code',
    width: '15%',
  }, {
    title: '视频名称',
    key: 2,
    dataIndex: 'name',
    width: '32%',
  }, {
    title: '视频格式',
    key: 3,
    dataIndex: 'format',
    width: '10%',
  }, {
    title: '视频质量',
    key: 4,
    dataIndex: 'quality',
    render: (text) => renderQuality(text),
    width: '10%',
  }, {
    title: '视频状态',
    key: 5,
    dataIndex: 'status',
    render: (text) => renderStatus(text),
    width: '10%',
  }, {
    title: '创建时间',
    key: 6,
    dataIndex: 'gmtModified',
    render: (text) => moment(text).format('YYYY-MM-DD'),
    width: '15%',
  }, {
    title: '操作',
    key: 8,
    dataIndex: 'operation',
    render: (_, record) => <a onClick={() => onModalCreate(record)}>播放</a>,
    width: '8%',
  }];
  return (
    <div>
      <StandardTableList
        columns={columns}
        loading={loading}
        dataSource={dataSource}
        header={{basicSearch, onFilterClick }}
        footer={{pagination, batchActions, onBatchClick}}
      />
      {!modalDestory &&
        <Modal
          title={currentItem.name}
          visible={true}
          footer={null}
          onCancel={onModalDestory}
          maskClosable={false}
          width={800}
        >
          <RBVideoPlayer
            width={'100%'}
            height={'100%'}
            url={currentItem.url}
            isM3U8={currentItem.format === 'm3u8' ? true : false}
          />
        </Modal>
      }
    </div>
  );
}

export default VideoTableList;
